Imagenet2012Fewshot is a subset of original ImageNet ILSVRC 2012 dataset. The
dataset share the *same* validation set as the original ImageNet ILSVRC 2012
dataset. However, the training set is subsampled in a label balanced fashion. In
`5shot` configuration, 5 images per label, or 5000 images are sampled; and in
`10shot` configuration, 10 images per label, or 10000 images are sampled.
